@@ -20,19 +20,19 @@
 #include "../kwalletmanager_version.h"
 #include "konfigurator.h"
 
-#include <ksharedconfig.h>
-#include <kpluginfactory.h>
-#include <kpluginloader.h>
+#include <KSharedConfig>
+#include <KPluginFactory>
+#include <KPluginLoader>
 #include <QInputDialog>
-#include <kwallet.h>
-#include <kauthaction.h>
-#include <kauthactionreply.h>
-#include <kauthexecutejob.h>
-#include <ktoolinvocation.h>
-#include <kconfiggroup.h>
-#include <kmessagebox.h>
+#include <KWallet>
+#include <KAuthAction>
+#include <KAuthActionReply>
+#include <KAuthExecuteJob>
+#include <KToolInvocation>
+#include <KConfigGroup>
+#include <KMessageBox>
 
-#include <kaboutdata.h>
+#include <KAboutData>
 
 #include <QDebug>
 #include <QCheckBox>
@@ -176,7 +176,7 @@ void KWalletConfig::newNetworkWallet()
 void KWalletConfig::launchManager()
 {
     if (!QDBusConnection::sessionBus().interface()->isServiceRegistered(QStringLiteral("org.kde.kwalletmanager5"))) {
-        QProcess::startDetached(QStringLiteral("kwalletmanager5 --show"));
+        QProcess::startDetached(QStringLiteral("kwalletmanager5 --show"), QStringList());
     } else {
         QDBusInterface kwalletd(QStringLiteral("org.kde.kwalletmanager5"), QStringLiteral("/kwalletmanager5/MainWindow_1"));
         kwalletd.call(QStringLiteral("show"));
